/******************************************************************************
* Project Name		: PSoC_4_BLE_LowPowerModes
* File Name			: main.c
* Version 			: 1.0
* Device Used		: CY8C4247LQI-BL483
* Software Used		: PSoC Creator 3.1
* Compiler    		: ARM GCC 4.8.4
* Related Hardware	: CY8CKIT-042-BLE Bluetooth Low Energy Pioneer Kit 
* Owner             : ANKU
*
********************************************************************************
* Copyright (2014-15), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/

/******************************************************************************
*                           THEORY OF OPERATION
*******************************************************************************
* This project will showcase the capability of PSoC 4 BLE to communicate 
* bi-directionally with a BLE Central device over custom services. 
* The LPM SEL custom service allows 
* read and write of attributes under the LPM characteristics.
* This allows the selection of the low power mode operation, ideal for battery operated 
* devices. The project utlizes Deep Sleep feature of both BLESS and CPU to remain 
* in low power mode as much as possible, while maintaining the BLE connection and  
* data transfer. This allows the device to run on coin cell battery for long time.
*
* Note:
* The programming pins have been configured as GPIO, and not SWD. This is because 
* when programming pins are configured for SWD, then the silicon consumes extra
* power through the pins. To prevent the leakage of power, the pins have been set 
* to GPIO. With this setting, the kit can still be acquired by PSoC Creator or
* PSoC Programmer software tools for programming, but the project cannot be 
* externally debugged. To re-enable debugging, go to PSoC_4_BLE_CapSense_Slider_LED.cydwr 
* from Workspace Explorer, go to Systems tab, and set the Debug Select option to 'SWD'.
* Build and program this project to enable external Debugging.
*
* Refer to BLE Pioneer Kit user guide for details.
*******************************************************************************
* Hardware connection required for testing -
* R-G-B LED 	- P2[6], P3[6] and P3[7] (hard-wired on the BLE Pioneer kit)
* User Switch	- P2[7] (hard-wired on the BLE Pioneer kit)
******************************************************************************/
#include <main.h>
   #include "RTC.c"
/* This flag is used by application to know whether a Central 
* device has been connected. This is updated in BLE event callback 
* function*/
extern uint8 deviceConnected;


/* 'restartAdvertisement' flag is used to restart advertisement */
extern uint8 restartAdvertisement;
unsigned char led,Pin1flag;
void wdt_intr(void)
{

    CySysWdtClearInterrupt(CY_SYS_WDT_COUNTER0_INT) ;

      //HandleLowPowerMode();
        //CySysPmDeepSleep();
                /* Device enters DeepSleep mode when CPU asserts SLEEPDEEP signal */
       // CyEnterCriticalSection();
       // CY_PM_PWR_CONTROL_REG &= (uint32) (~CY_PM_PWR_CONTROL_HIBERNATE);
            /* CPU enters DeepSleep/Hibernate mode upon execution of WFI */
    //CY_PM_CPU_SCR_REG |= CY_PM_CPU_SCR_SLEEPDEEP;
        
}
    uint64 RTC_GetDstUnixTime1(const RTC_DST_TIME* dstTime)
    {
        uint32 tmpYear;
        uint32 tmpDate;
        uint64 dstUnixTime;

        RTC_DATE_TIME tmpTimeDate;

        RTC_UnixToDateTime(&tmpTimeDate, RTC_unixTime, RTC_INITIAL_TIME_FORMAT);
        tmpYear = RTC_GetYear(tmpTimeDate.date);
        //if data over the dst stop then increment year
            //LCD_Position(0,6);
            //LCD_PrintU32Number(RTC_unixTime);
            //LCD_Position(1,6);
            //LCD_PrintU32Number(RTC_dstTimeOffset);
        if(RTC_unixTimeDstStop<=(RTC_unixTime-RTC_dstTimeOffset))//Next year
        {
            tmpYear++;
        }
        if(dstTime->timeFormat == (uint8)RTC_DST_DATE_FIXED)
        {
            tmpDate =  RTC_ConstructDate(dstTime->month, dstTime->dayOfMonth, tmpYear);
        }
        else
        {
            tmpDate = 
            RTC_RelativeToFixed(dstTime->dayOfWeek, dstTime->weekOfMonth, dstTime->month, tmpYear);
        }

        tmpTimeDate.time = 
        RTC_ConstructTime((uint32)RTC_24_HOURS_FORMAT, 0u, dstTime->hour, 0u, 0u);
        dstUnixTime = RTC_DateTimeToUnix(tmpDate, tmpTimeDate.time);

        return(dstUnixTime);
    }
    void RTC_SetDateAndTime1(uint32 inputTime, uint32 inputDate)
    {
        uint32 tmpDay;
        uint32 tmpMonth;
        uint32 tmpYear;

        tmpDay   = RTC_GetDay(inputDate);
        tmpMonth = RTC_GetMonth(inputDate);
        tmpYear  = RTC_GetYear(inputDate);

        RTC_unixTime = RTC_DateTimeToUnix(inputDate, inputTime);
        RTC_currentTimeDate.date = inputDate;
        RTC_currentTimeDate.time = inputTime;
        RTC_currentTimeDate.dayOfWeek = RTC_GetDayOfWeek(tmpDay, tmpMonth, tmpYear);

        RTC_unixTimeDstStart = RTC_GetDstUnixTime1(&RTC_dstStartTime);
        RTC_unixTimeDstStop  = RTC_GetDstUnixTime1(&RTC_dstStopTime);

        if((RTC_unixTime >= RTC_unixTimeDstStart) &&
           (RTC_unixTime <= RTC_unixTimeDstStop))
        {
            RTC_dstStatus = 1u;
            RTC_dstTimeOffset = RTC_SECONDS_PER_HOUR;
            RTC_unixTime -= RTC_dstTimeOffset;
        }
        else
        {
            RTC_dstStatus = 0u;
            RTC_dstTimeOffset = 0uL;
        }
}
    void RTC_SetDSTStartTime1(const RTC_DST_TIME* dstStartTime, RTC_DST_DATETYPE_ENUM type)
    {
        RTC_dstStartTime.timeFormat    = (uint8)type;
        RTC_dstStartTime.hour          = dstStartTime->hour;
        RTC_dstStartTime.dayOfWeek     = dstStartTime->dayOfWeek;
        RTC_dstStartTime.weekOfMonth   = dstStartTime->weekOfMonth;
        RTC_dstStartTime.dayOfMonth    = dstStartTime->dayOfMonth;
        RTC_dstStartTime.month         = dstStartTime->month;

        RTC_unixTimeDstStart = RTC_GetDstUnixTime1(&RTC_dstStartTime);

        if((RTC_unixTime >= RTC_unixTimeDstStart) &&
           (RTC_unixTime <= RTC_unixTimeDstStop))
        {
            RTC_dstStatus = 1u;
            RTC_dstTimeOffset = RTC_SECONDS_PER_HOUR;
        }
        else
        {
            RTC_dstStatus = 0u;
            RTC_dstTimeOffset = 0uL;
        }
    }
void RTC_Init1(void)
{
    uint32 tmpDate;
    uint32 tmpTime;
    
    RTC_DST_TIME dstTimeTmp;

    RTC_initVar = 1u;
    RTC_dstTimeOffset = 0uL;
    RTC_currentTimeDate.status = 0uL;

    RTC_dstStatus      = RTC_INITIAL_DST_STATUS;
    RTC_alarmCurStatus = RTC_INITIAL_ALARM_STATUS;

    tmpDate = RTC_ConstructDate(RTC_INITIAL_MONTH,
                                             RTC_INITIAL_DAY,
                                             RTC_INITIAL_YEAR);

    tmpTime = RTC_ConstructTime(RTC_INITIAL_TIME_FORMAT,
                                             0u,
                                            RTC_INITIAL_HOUR,
                                            RTC_INITIAL_MINUTE,
                                            RTC_INITIAL_SECOND);
    RTC_SetDateAndTime1(tmpTime, tmpDate);
  //  RTC_unixTimeDstStop  = RTC_GetDstUnixTime1(&RTC_dstStopTime);

        RTC_dstStatus = 0u;
        RTC_currentTimeDate.status = (1uL << RTC_STATUS_DST_OFFSET);

        dstTimeTmp.timeFormat    = RTC_INITIAL_DST_DATE_TYPE;
        dstTimeTmp.hour          = RTC_INITIAL_DST_START_HRS;
        dstTimeTmp.dayOfWeek     = RTC_INITIAL_DST_START_DOW;
        dstTimeTmp.weekOfMonth   = RTC_INITIAL_DST_START_WOM;
        dstTimeTmp.dayOfMonth    = RTC_INITIAL_DST_START_DOM;
        dstTimeTmp.month         = RTC_INITIAL_DST_START_MONTH;
        RTC_SetDSTStartTime1(&dstTimeTmp, 
                                        (RTC_DST_DATETYPE_ENUM)RTC_INITIAL_DST_DATE_TYPE);

        dstTimeTmp.timeFormat    = RTC_INITIAL_DST_DATE_TYPE;
        dstTimeTmp.hour          = RTC_INITIAL_DST_STOP_HRS;
        dstTimeTmp.dayOfWeek     = RTC_INITIAL_DST_STOP_DOW;
        dstTimeTmp.weekOfMonth   = RTC_INITIAL_DST_STOP_WOM;
        dstTimeTmp.dayOfMonth    = RTC_INITIAL_DST_STOP_DOM;
        dstTimeTmp.month         = RTC_INITIAL_DST_STOP_MONTH;
        RTC_SetDSTStopTime(&dstTimeTmp, 
                                       (RTC_DST_DATETYPE_ENUM)RTC_INITIAL_DST_DATE_TYPE);

        RTC_unixTimeDstStart = RTC_GetDstUnixTime1(&RTC_dstStartTime);
        RTC_unixTimeDstStart -= (uint64) 2 * RTC_SECONDS_PER_DAY;//correction for jew dst
        RTC_unixTimeDstStop  = RTC_GetDstUnixTime1(&RTC_dstStopTime);

        if((RTC_unixTime >= RTC_unixTimeDstStart) &&
           (RTC_unixTime <= RTC_unixTimeDstStop))
        {
            RTC_dstStatus = 1u;
            RTC_dstTimeOffset = RTC_SECONDS_PER_HOUR;
        }

    
}

void RTC_Update1(void)
{
    RTC_DATE_TIME tmpTimeDate;
    static uint32 RTC_currentTickNumber = 0u;
    RTC_currentTickNumber += RTC_updateTimePeriod;

    if(RTC_currentTickNumber >= RTC_tickRefOneSec)
    {
        RTC_unixTime++;
        RTC_currentTickNumber = (uint32) RTC_currentTickNumber - RTC_tickRefOneSec;
        
        if(RTC_unixTime == RTC_unixTimeDstStart)
        {
            RED_Write(RGB_LED_ON);
            RTC_dstStatus = 1u;
            RTC_dstTimeOffset = RTC_SECONDS_PER_HOUR;
        }

        if(RTC_unixTime == (RTC_unixTimeDstStop - RTC_dstTimeOffset))
        {
            RED_Write(RGB_LED_OFF);
            RTC_dstStatus = 0u;
            RTC_dstTimeOffset = 0u;
            //RTC_dstStartTime -=
            //add one year here
             //RTC_SetDSTStartTime(&RTC_dstStartTime, (RTC_DST_DATETYPE_ENUM)RTC_INITIAL_DST_DATE_TYPE);
            RTC_unixTimeDstStart = RTC_GetDstUnixTime1(&RTC_dstStartTime);
            RTC_unixTimeDstStart -= (uint64) 2 * RTC_SECONDS_PER_DAY;//correction for jew dst
            RTC_unixTimeDstStop  = RTC_GetDstUnixTime1(&RTC_dstStopTime);
        }
    }
}

int main()
{ 

    unsigned char hours,hours1,min,min1,diff,mode;
    RTC_DATE_TIME Start;
    Start.time = 1;
    Start.date = 2;
    Start.dayOfWeek = 3;
    Start.status = 4;
//LCD_LCDPort_SetDriveMode(LCD_LCDPort_DM_OD_LO);
            /*
        #define LCD_LCDPort_DM_ALG_HIZ         (0x00u) //< \brief High Impedance Analog   
        #define LCD_LCDPort_DM_DIG_HIZ         (0x01u) //< \brief High Impedance Digital  
        #define LCD_LCDPort_DM_RES_UP          (0x02u) //< \brief Resistive Pull Up       
        #define LCD_LCDPort_DM_RES_DWN         (0x03u) //< \brief Resistive Pull Down     
        #define LCD_LCDPort_DM_OD_LO           (0x04u) //< \brief Open Drain, Drives Low  
        #define LCD_LCDPort_DM_OD_HI           (0x05u) //< \brief Open Drain, Drives High 
        #define LCD_LCDPort_DM_STRONG          (0x06u) //< \brief Strong Drive            
        #define LCD_LCDPort_DM_RES_UPDWN       (0x07u) //< \brief Resistive Pull Up/Down  
        */ 
    //RTC_DATE_TIME TimeDate;

    
    //Start.time = 55u;
    
//    RTC_DST_TIME Start;
	/* This function will initialize the system resources such as BLE and CapSense */
    InitializeSystem();
	//HandleLowPowerMode();
    isr_pin1_Start();
    			/* Put system to Deep sleep, including BLESS, and wakeup on interrupt. 
			* The source of the interrupt can be either BLESS Link Layer in case of 
			* BLE advertisement and connection or by User Button press during BLE 
			* disconnection */
    LCD_Start();
    RTC_Init1();
               // LCD_Position(0,6);
            //LCD_PrintU32Number(RTC_unixTimeDstStart);
            //RTC_unixTimeDstStart -= (uint64) 2 * RTC_SECONDS_PER_DAY;//correction for jew dst
            //LCD_Position(1,6);
            //LCD_PrintU32Number(RTC_unixTimeDstStart);
    LCD_PrintString("Clock");
    hours=100;
    mode=1;
    RED_Write(RGB_LED_OFF);

    while(1)
    {
        //
       // Pin1flag=0;

      //  CySysPmDeepSleep();
        
        RTC_Update1();
        //RTC_unixTimeDstStart-=5;//-=48*60*60;//correction for jew dst 
       
       //if(led)
		//{
				/* Switch of Status LED */
	//			RED_Write(RGB_LED_OFF);
				/* Reset the Flag */
//				led = FALSE;
//		}
//		else
//		{
				/* Shut down LEDs*/
  //          RED_Write(RGB_LED_ON);
      //      led = TRUE;
	//	}
        /*Get the current RTC time and date */
        RTC_GetDateAndTime(&Start);        
       

        //LCD_PrintU32Number(RTC_unixTimeDstStart);
       //  RTC_unixTimeDstStart += (uint64) 2 * RTC_SECONDS_PER_DAY;
        hours1=hours;
        min1=min;
        hours=RTC_GetHours(Start.time);
        min=RTC_GetMinutes(Start.time);
       // LCD_PrintU32Number(RTC_unixTimeDstStart);
       // LCD_PrintString(RTC_DATE_TIME dateTime);
       // CyDelay(10);
        
        //UART_PutString("ABCD");
       // UART_Start();
       // UART_Stop();
        diff=0;
        if(((min==0)&&(min1==59)))
        {
            LCD_Position(0,0);
            LCD_PrintNumber(RTC_GetDay(Start.date));
            LCD_PrintString(":");
            LCD_PrintNumber(RTC_GetMonth(Start.date));
            LCD_PrintString(":");
            LCD_PrintNumber(RTC_GetYear( Start.date));
            //LCD_PrintU32Number(RTC_unixTimeDstStart);
            LCD_PrintString("   ");
            LCD_Position(1,0);
            LCD_PrintNumber(hours);
            LCD_PrintString(":");
            LCD_PrintNumber(RTC_GetMinutes(Start.time));
            LCD_PrintString(":");
            LCD_PrintNumber(RTC_GetSecond(Start.time));
            LCD_PrintString("   ");
            if(hours>hours1)
            {
                diff=hours-hours1;
                if((diff>1)&&(mode==1)) 
                {
                    mode=0;
                  //  LCD_PrintString("Summer"); 
                }
                else diff=0;
            }
            else if((hours==hours1)&&(mode==0))
            {
            
               // LCD_PrintString("   ");
                mode=1;
               // LCD_PrintString("Winter"); 
                diff=1;
            }
            if(diff)
            {
                                LCD_Position(0,6);
            LCD_PrintU32Number(RTC_unixTimeDstStart);
                                            LCD_Position(1,6);
            LCD_PrintU32Number(RTC_unixTimeDstStop);
                CyDelay(1000);
                Pin1flag=0;
                while(Pin1flag==0);
                CyDelay(1000);
                Pin1flag=0;
                LCD_Position(1,0);
                LCD_PrintString("                "); 
            }
        } 
    }
}

/*******************************************************************************
* Function Name: InitializeSystem
********************************************************************************
* Summary:
*        Start the components and initialize system 
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void InitializeSystem(void)
{
	/* Enable global interrupt mask */
	CyGlobalIntEnable; 
	//CySysWdtEnable(CY_SYS_WDT_COUNTER0_MASK);	
        
    isr_wdt_ClearPending() ;
    //isr_wdt_StartEx(wdt_intr) ;
    
	/* Start BLE component and register the CustomEventHandler function. This 
	* function exposes the events from BLE component for application use */
    CyBle_Start(CustomEventHandler);
	
	/* Set Drive mode of output pins from HiZ to Strong */
	RED_SetDriveMode(RED_DM_STRONG);

	
	/* Start the Button ISR to allow wakeup from sleep */
	//isr_button_StartEx(MyISR);
	
	/* Set the Watchdog Interrupt vector to the address of Interrupt routine 
	* WDT_INT_Handler. This routine counts the 3 seconds for LED ON state during
	* connection. */
	//CyIntSetVector(WATCHDOG_INT_VEC_NUM, &WDT_INT_Handler);
}

/* [] END OF FILE */
